ParentTransactionCache

Struct ParentTransactionCache 

pub struct ParentTransactionCache { /* private fields */ }

Implementations

Source

impl ParentTransactionCache

pub fn get_parent_transaction_hash( &self, receipt_id: &ReceiptId, ) -> Option<TransactionHash>

Returns the parent transaction hash for a given receipt id. If the receipt id is not found in the cache, it returns None. If the receipt id is found in the cache, it returns the parent transaction hash.