ParentTransactionCacheBuilder

Struct ParentTransactionCacheBuilder 

pub struct ParentTransactionCacheBuilder { /* private fields */ }
Implementations

Source

impl ParentTransactionCacheBuilder

pub fn build( self, ) -> Result<ParentTransactionCache, ParentTransactionCacheBuilderError>

Builds a new ParentTransactionCache.

Errors

If a required field has not been initialized.

Source

impl ParentTransactionCacheBuilder

pub fn cache_size(self, value: usize) -> Self

Sets the size of the cache. Default is 100_000.

pub fn for_accounts(self, accounts_id: Vec<AccountId>) -> Self

Stores the Vec of AccountId to cache transactions for. If not set, the cache will be created for all the Transactions in the block. If set the cache will be created only for the transactions that have the sender or receiver in the list of accounts. Warning: This method overrides the previous value.

pub fn for_account(self, account_id: AccountId) -> Self

Adds an account to the watching list for the parent transaction cache. Similarly to the method for_accounts this method will create the cache only for the transactions that have the sender or receiver in the list of accounts. Warning: This method appends to the previous value.