pub struct ParentTransactionCache { /* private fields */ }Implementations
Sourceimpl ParentTransactionCache
impl ParentTransactionCache
Sourcepub fn get_parent_transaction_hash(
&self,
receipt_id: &ReceiptId,
) -> Option<TransactionHash>
pub fn get_parent_transaction_hash( &self, receipt_id: &ReceiptId, ) -> Option<TransactionHash>
Returns the parent transaction hash for a given receipt id. If the receipt id is not found in the cache, it returns None. If the receipt id is found in the cache, it returns the parent transaction hash.